BoxyFlexible class

A widget that controls how a child of a BoxyRow, BoxyColumn, or BoxyFlex flexes.

This is the same as Flexible but adds dominant and crossAxisAlignment.

See also:

  • Dominant, a convenient wrapper around this widget.
Inheritance
Implementers

Constructors

BoxyFlexible({Key? key, int flex = 1, FlexFit fit = FlexFit.loose, bool dominant = false, CrossAxisAlignment? crossAxisAlignment, required Widget child})
Creates a widget that controls how a child of a Row, Column, or Flex flexes.
const
BoxyFlexible.align({Key? key, int flex = 0, FlexFit fit = FlexFit.loose, bool dominant = false, required CrossAxisAlignment? crossAxisAlignment, required Widget child})
Same as the default constructor but has a flex factor of 0, and makes crossAxisAlignment a required argument.
const

Properties

child → Widget
The widget below this widget in the tree.
finalinherited
crossAxisAlignment → CrossAxisAlignment?
The cross axis alignment of this child, overrides the default alignment specified by the BoxyFlex.
final
debugTypicalAncestorWidgetClass → Type
Describes the RenderObjectWidget that is typically used to set up the ParentData that applyParentData will write to.
no setteroverride
debugTypicalAncestorWidgetDescription → String
Describes the RenderObjectWidget that is typically used to set up the ParentData that applyParentData will write to.
no setterinherited
dominant → bool
Whether this child should determine the maximum cross axis size of every other child.
final
fit → FlexFit
How a flexible child is inscribed into the available space.
final
flex → int
The flex factor to use for this child
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyParentData(RenderObject renderObject) → void
Write the data from this widget into the given render object's parent data.
override
createElement() → ParentDataElement<FlexParentData>
Inflates this configuration to a concrete instance.
inherited
debugCanApplyOutOfTurn() → bool
Whether the ParentDataElement.applyWidgetOutOfTurn method is allowed with this widget.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
debugIsValidRenderObject(RenderObject renderObject) → bool
Checks if this widget can apply its parent data to the provided renderObject.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited